@@ -716,6 +716,18 @@ def test_upper_alpha_all_bold():
     ''')
 
 
+def test():
+    file_path = path.join('/home/jason/Downloads/Discharge Planning referral.docx')
+    actual_html = convert(file_path)
+    assert_html_equal(actual_html, '''
+    <html>
+        <h2>AAA</h2>
+        <h2>BBB</h2>
+        <h2>CCC</h2>
+    </html>
+    ''')
+
+
 def _converter(*args, **kwargs):
     # Having a converter that does nothing is the same as if abiword fails to
     # convert.
